@@ -1,12 +1,13 @@
 package MooseX::ClassCompositor;
 {
-  $MooseX::ClassCompositor::VERSION = '0.007';
+  $MooseX::ClassCompositor::VERSION = '0.008';
 }
 use Moose;
 # ABSTRACT: a factory that builds classes from roles
 
 use namespace::autoclean;
 
+use Class::Load;
 use Moose::Util qw(apply_all_roles);
 use Moose::Util::MetaRole ();
 use MooseX::StrictConstructor::Trait::Class;
@@ -112,7 +113,7 @@ sub class_for {
       my ($role_name, $moniker, $params) = @$name;
 
       my $full_name = $self->_rewrite_roles($role_name);
-      Class::MOP::load_class($full_name);
+      Class::Load::load_class($full_name);
       my $role_object = $full_name->meta->generate_role(
         parameters => $params,
       );
@@ -147,7 +148,7 @@ sub class_for {
 
   @role_class_names = $self->_rewrite_roles(@role_class_names);
 
-  Class::MOP::load_class($_) for @role_class_names;
+  Class::Load::load_class($_) for @role_class_names;
 
   if ($name->can('meta')) {
     $name .= "_" . $self->next_serial;
@@ -211,13 +212,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::ClassCompositor - a factory that builds classes from roles
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
